pub async fn test_stream<L, R, E1, E2>(left: L, right: R)Expand description
Test transport by collecting received messages while treating transport as a stream.
It verifies if transport closing (or dropping) on one side is communicated to the other side - without it, stream would never complete.