pub async fn test_unit_message<L, R, E1, E2>(left: L, right: R)Expand description
Test transport by sending units (()) between two connected instances.
When used with BincodeCodec it can verify sending message of length 0 (in bytes) works.
pub async fn test_unit_message<L, R, E1, E2>(left: L, right: R)Test transport by sending units (()) between two connected instances.
When used with BincodeCodec it can verify sending message of length 0 (in bytes) works.