Common tests for dnet transport implementations.
Macros
- dtest_
configure - Configure WASM tests to run in browser.
Functions
- init_
logging - Init tracing subscriber and enable logging for given transports.
- test_
stream - Test transport by collecting received messages while treating transport as a stream.
- test_
stream_ with_ sleep_ before_ drop - Same as test_stream except we sleep for specified duration before dropping the sending transport.
- test_
transport - Test transport by sending strings and integers between two connected instances.
- test_
unit_ message - Test transport by sending units (
()) between two connected instances.
Attribute Macros
- dtest
- Convenience attribute macro for marking tests that need to run for both native and WASM targets.